@@ -1,4 +1,4 @@
-#   Copyright 2012 OpenStack Foundation
+#   Copyright 2012 OpenStack, LLC.
 #
 #   Licensed under the Apache License, Version 2.0 (the "License"); you may
 #   not use this file except in compliance with the License. You may obtain
@@ -15,6 +15,7 @@
 from cinder.api import extensions
 from cinder.api.openstack import wsgi
 from cinder.api import xmlutil
+from cinder import volume
 
 
 authorize = extensions.soft_extension_authorizer('volume',
@@ -22,26 +23,33 @@ authorize = extensions.soft_extension_authorizer('volume',
 
 
 class VolumeTenantAttributeController(wsgi.Controller):
-    def _add_volume_tenant_attribute(self, req, resp_volume):
-        db_volume = req.get_db_volume(resp_volume['id'])
-        key = "%s:tenant_id" % Volume_tenant_attribute.alias
-        resp_volume[key] = db_volume['project_id']
+    def __init__(self, *args, **kwargs):
+        super(VolumeTenantAttributeController, self).__init__(*args, **kwargs)
+        self.volume_api = volume.API()
+
+    def _add_volume_tenant_attribute(self, context, resp_volume):
+        try:
+            db_volume = self.volume_api.get(context, resp_volume['id'])
+        except Exception:
+            return
+        else:
+            key = "%s:tenant_id" % Volume_tenant_attribute.alias
+            resp_volume[key] = db_volume['project_id']
 
     @wsgi.extends
     def show(self, req, resp_obj, id):
         context = req.environ['cinder.context']
         if authorize(context):
             resp_obj.attach(xml=VolumeTenantAttributeTemplate())
-            volume = resp_obj.obj['volume']
-            self._add_volume_tenant_attribute(req, volume)
+            self._add_volume_tenant_attribute(context, resp_obj.obj['volume'])
 
     @wsgi.extends
     def detail(self, req, resp_obj):
         context = req.environ['cinder.context']
         if authorize(context):
             resp_obj.attach(xml=VolumeListTenantAttributeTemplate())
-            for vol in list(resp_obj.obj['volumes']):
-                self._add_volume_tenant_attribute(req, vol)
+            for volume in list(resp_obj.obj['volumes']):
+                self._add_volume_tenant_attribute(context, volume)
 
 
 class Volume_tenant_attribute(extensions.ExtensionDescriptor):
@@ -50,7 +58,7 @@ class Volume_tenant_attribute(extensions.ExtensionDescriptor):
     name = "VolumeTenantAttribute"
     alias = "os-vol-tenant-attr"
     namespace = ("http://docs.openstack.org/volume/ext/"
-                 "volume_tenant_attribute/api/v2")
+                 "volume_tenant_attribute/api/v1")
     updated = "2011-11-03T00:00:00+00:00"
 
     def get_controller_extensions(self):
