@@ -1,4 +1,6 @@
-# Copyright 2011 OpenStack Foundation
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
+# Copyright 2011 OpenStack LLC.
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -13,12 +15,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import re
-from urllib.request import parse_http_list
-
 import paste.urlmap
+import re
+import urllib2
 
 from cinder.api.openstack import wsgi
+from cinder.openstack.common import log as logging
 
 
 _quoted_string_re = r'"[^"\\]*(?:\\.[^"\\]*)*"'
@@ -27,10 +29,11 @@ _option_header_piece_re = re.compile(
     r'(?:=\s*([^;]+|%s))?\s*' %
     (_quoted_string_re, _quoted_string_re))
 
+LOG = logging.getLogger(__name__)
+
 
 def unquote_header_value(value):
     """Unquotes a header value.
-
     This does not use the real unquoting but what browsers are actually
     using for quoting.
 
@@ -62,7 +65,7 @@ def parse_list_header(value):
     :return: :class:`list`
     """
     result = []
-    for item in parse_http_list(value):
+    for item in urllib2.parse_http_list(value):
         if item[:1] == item[-1:] == '"':
             item = unquote_header_value(item[1:-1])
         result.append(item)
@@ -70,9 +73,7 @@ def parse_list_header(value):
 
 
 def parse_options_header(value):
-    """Parse 'Content-Type'-like header into a tuple.
-
-    Parse a ``Content-Type`` like header into a tuple with the content
+    """Parse a ``Content-Type`` like header into a tuple with the content
     type and the options:
 
     >>> parse_options_header('Content-Type: text/html; mimetype=text/html')
@@ -93,7 +94,7 @@ def parse_options_header(value):
         return '', {}
 
     parts = _tokenize(';' + value)
-    name = next(parts)[0]
+    name = parts.next()[0]
     extra = dict(parts)
     return name, extra
 
@@ -252,7 +253,7 @@ class URLMap(paste.urlmap.URLMap):
 
         # The MIME type for the response is determined in one of two ways:
         # 1) URL path suffix (eg /servers/detail.json)
-        # 2) Accept header (eg application/json;q=0.8)
+        # 2) Accept header (eg application/json;q=0.8, application/xml;q=0.2)
 
         # The API version is determined in one of three ways:
         # 1) URL path prefix (eg /v1.1/tenant/servers/detail)
@@ -263,6 +264,11 @@ class URLMap(paste.urlmap.URLMap):
 
         mime_type, app, app_url = self._path_strategy(host, port, path_info)
 
+        # Accept application/atom+xml for the index query of each API
+        # version mount point as well as the root index
+        if (app_url and app_url + '/' == path_info) or path_info == '/':
+            supported_content_types.append('application/atom+xml')
+
         if not app:
             app = self._content_type_strategy(host, port, environ)
 
