@@ -142,8 +142,12 @@ class SnapshotsController(wsgi.Controller):
         """Returns a list of snapshots, transformed through entity_maker."""
         context = req.environ['cinder.context']
 
-        search_opts = {}
-        search_opts.update(req.GET)
+        #pop out limit and offset , they are not search_opts
+        search_opts = req.GET.copy()
+        search_opts.pop('limit', None)
+        search_opts.pop('offset', None)
+
+        #filter out invalid option
         allowed_search_options = ('status', 'volume_id', 'name')
         volumes.remove_invalid_options(context, search_opts,
                                        allowed_search_options)
@@ -223,9 +227,15 @@ class SnapshotsController(wsgi.Controller):
         valid_update_keys = (
             'name',
             'description',
+            'display_name',
             'display_description',
         )
 
+        # NOTE(thingee): v2 API allows name instead of display_name
+        if 'name' in snapshot:
+            snapshot['display_name'] = snapshot['name']
+            del snapshot['name']
+
         # NOTE(thingee): v2 API allows description instead of
         # display_description
         if 'description' in snapshot:
@@ -236,11 +246,6 @@ class SnapshotsController(wsgi.Controller):
             if key in snapshot:
                 update_dict[key] = snapshot[key]
 
-        # NOTE(thingee): v2 API allows name instead of display_name
-        if 'name' in update_dict:
-            update_dict['display_name'] = update_dict['name']
-            del update_dict['name']
-
         try:
             snapshot = self.volume_api.get_snapshot(context, id)
             self.volume_api.update_snapshot(context, snapshot, update_dict)
