@@ -16,14 +16,8 @@
 # Importing full names to not pollute the namespace and cause possible
 # collisions with use of 'from cinder.backup import <foo>' elsewhere.
 
-from oslo_utils import importutils
+import cinder.flags
+import cinder.openstack.common.importutils
 
-from cinder.common import config
-
-
-CONF = config.CONF
-
-
-def API(*args, **kwargs):
-    class_name = CONF.backup_api_class
-    return importutils.import_object(class_name, *args, **kwargs)
+API = cinder.openstack.common.importutils.import_class(
+        cinder.flags.FLAGS.backup_api_class)
