@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
 #    a copy of the License at
@@ -23,3 +25,12 @@ def upgrade(migrate_engine):
     provider_location = Column('provider_location', String(255))
     snapshots.create_column(provider_location)
     snapshots.update().values(provider_location=None).execute()
+
+
+def downgrade(migrate_engine):
+    meta = MetaData()
+    meta.bind = migrate_engine
+
+    snapshots = Table('snapshots', meta, autoload=True)
+    provider_location = snapshots.columns.provider_location
+    snapshots.drop_column(provider_location)
