@@ -24,30 +24,28 @@ inline callbacks.
 """
 
 import functools
-import uuid
 import unittest
+import uuid
 
 import mox
 import nose.plugins.skip
+from oslo.config import cfg
 import stubout
 
 from cinder import flags
 from cinder.openstack.common import log as logging
-from cinder.openstack.common import cfg
 from cinder.openstack.common import timeutils
 from cinder import service
 from cinder import tests
 from cinder.tests import fake_flags
 
-
 test_opts = [
     cfg.StrOpt('sqlite_clean_db',
                default='clean.sqlite',
                help='File name of clean sqlite db'),
     cfg.BoolOpt('fake_tests',
                 default=True,
-                help='should we use everything for testing'),
-    ]
+                help='should we use everything for testing'), ]
 
 FLAGS = flags.FLAGS
 FLAGS.register_opts(test_opts)
@@ -138,6 +136,7 @@ class TestCase(unittest.TestCase):
         self.stubs = stubout.StubOutForTesting()
         self.injected = []
         self._services = []
+        FLAGS.set_override('fatal_exception_format_errors', True)
 
     def tearDown(self):
         """Runs after each test method to tear down test environment."""
