@@ -17,9 +17,9 @@
 
 from lxml import etree
 
+from cinder.api import common
 from cinder.openstack.common import log as logging
 from cinder.tests.integrated import integrated_helpers
-from cinder.api.openstack import common
 
 
 LOG = logging.getLogger(__name__)
