@@ -38,6 +38,11 @@ class TargetAdminTestCase(object):
         self.stubs.Set(os.path, 'isfile', lambda _: True)
         self.stubs.Set(os, 'unlink', lambda _: '')
         self.stubs.Set(iscsi.TgtAdm, '_get_target', self.fake_get_target)
+        self.stubs.Set(iscsi.LioAdm, '_get_target', self.fake_get_target)
+        self.stubs.Set(iscsi.LioAdm, '__init__', self.fake_init)
+
+    def fake_init(obj):
+        return
 
     def fake_get_target(obj, iqn):
         return 1
@@ -56,7 +61,7 @@ class TargetAdminTestCase(object):
         return "", None
 
     def clear_cmds(self):
-        cmds = []
+        self.cmds = []
 
     def verify_cmds(self, cmds):
         self.assertEqual(len(cmds), len(self.cmds))
@@ -76,7 +81,7 @@ class TargetAdminTestCase(object):
         tgtadm = iscsi.get_target_admin()
         tgtadm.set_execute(self.fake_execute)
         tgtadm.create_iscsi_target(self.target_name, self.tid,
-                self.lun, self.path)
+                                   self.lun, self.path)
         tgtadm.show_target(self.tid, iqn=self.target_name)
         tgtadm.remove_iscsi_target(self.tid, self.lun, self.vol_id)
 
@@ -95,8 +100,9 @@ class TgtAdmTestCase(test.TestCase, TargetAdminTestCase):
         self.flags(iscsi_helper='tgtadm')
         self.flags(volumes_dir=self.persist_tempdir)
         self.script_template = "\n".join([
-        'tgt-admin --update iqn.2011-09.org.foo.bar:blaa',
-        'tgt-admin --force --delete iqn.2010-10.org.openstack:volume-blaa'])
+            'tgt-admin --update iqn.2011-09.org.foo.bar:blaa',
+            'tgt-admin --force '
+            '--delete iqn.2010-10.org.openstack:volume-blaa'])
 
     def tearDown(self):
         try:
@@ -113,9 +119,22 @@ class IetAdmTestCase(test.TestCase, TargetAdminTestCase):
         TargetAdminTestCase.setUp(self)
         self.flags(iscsi_helper='ietadm')
         self.script_template = "\n".join([
-        'ietadm --op new --tid=%(tid)s --params Name=%(target_name)s',
-        'ietadm --op new --tid=%(tid)s --lun=%(lun)s '
-                '--params Path=%(path)s,Type=fileio',
-        'ietadm --op show --tid=%(tid)s',
-        'ietadm --op delete --tid=%(tid)s --lun=%(lun)s',
-        'ietadm --op delete --tid=%(tid)s'])
+            'ietadm --op new --tid=%(tid)s --params Name=%(target_name)s',
+            'ietadm --op new --tid=%(tid)s --lun=%(lun)s '
+            '--params Path=%(path)s,Type=fileio',
+            'ietadm --op show --tid=%(tid)s',
+            'ietadm --op delete --tid=%(tid)s --lun=%(lun)s',
+            'ietadm --op delete --tid=%(tid)s'])
+
+
+class LioAdmTestCase(test.TestCase, TargetAdminTestCase):
+
+    def setUp(self):
+        super(LioAdmTestCase, self).setUp()
+        TargetAdminTestCase.setUp(self)
+        self.persist_tempdir = tempfile.mkdtemp()
+        self.flags(iscsi_helper='lioadm')
+        self.script_template = "\n".join([
+            'cinder-rtstool create '
+                '/foo iqn.2011-09.org.foo.bar:blaa test_id test_pass',
+            'cinder-rtstool delete iqn.2010-10.org.openstack:volume-blaa'])
