@@ -937,6 +937,8 @@ class LVMVolumeDriverTestCase(DriverTestCase):
         configuration = conf.Configuration(fake_opt, 'fake_group')
         configuration.volume_clear = 'zero'
         configuration.volume_clear_size = 0
+        configuration.volume_driver = \
+            'cinder.volume.drivers.lvm.LVMISCSIDriver'
         lvm_driver = lvm.LVMVolumeDriver(configuration=configuration)
         self.stubs.Set(lvm_driver, '_copy_volume', lambda *a, **kw: True)
 
@@ -956,6 +958,48 @@ class LVMVolumeDriverTestCase(DriverTestCase):
         volume = dict(fake_volume)
         self.assertEquals(None, lvm_driver.clear_volume(volume))
 
+    def test_clear_volume_thinlvm_snap(self):
+        self.stubs.Set(os.path, 'exists', lambda x: True)
+        configuration = conf.Configuration(fake_opt, 'fake_group')
+        configuration.volume_clear = 'zero'
+        configuration.volume_clear_size = 0
+        configuration.volume_driver = \
+            'cinder.volume.drivers.lvm.ThinLVMVolumeDriver'
+        lvm_driver = lvm.ThinLVMVolumeDriver(configuration=configuration)
+
+        def fake_copy_volume(srcstr, deststr, size, **kwargs):
+            self.assertEqual(deststr, '/dev/mapper/cinder--volumes-snap1')
+            return True
+
+        self.stubs.Set(lvm_driver, '_copy_volume', fake_copy_volume)
+
+        fake_snapshot = {'name': 'snap1',
+                         'id': 'snap1',
+                         'size': 123}
+
+        lvm_driver.clear_volume(fake_snapshot, is_snapshot=True)
+
+    def test_clear_volume_lvm_snap(self):
+        self.stubs.Set(os.path, 'exists', lambda x: True)
+        configuration = conf.Configuration(fake_opt, 'fake_group')
+        configuration.volume_clear = 'zero'
+        configuration.volume_clear_size = 0
+        configuration.volume_driver = \
+            'cinder.volume.drivers.lvm.LVMISCSIDriver'
+        lvm_driver = lvm.LVMISCSIDriver(configuration=configuration)
+
+        def fake_copy_volume(srcstr, deststr, size, **kwargs):
+            self.assertEqual(deststr, '/dev/mapper/cinder--volumes-snap1-cow')
+            return True
+
+        self.stubs.Set(lvm_driver, '_copy_volume', fake_copy_volume)
+
+        fake_snapshot = {'name': 'snap1',
+                         'id': 'snap1',
+                         'size': 123}
+
+        lvm_driver.clear_volume(fake_snapshot, is_snapshot=True)
+
 
 class ISCSITestCase(DriverTestCase):
     """Test Case for ISCSIDriver"""
